#!/Users/mikka/code/lights/.venv/bin/python

import rumps
from phue import Bridge
import webbrowser

class HueLightsApp(rumps.App):
    def __init__(self):
        super(HueLightsApp, self).__init__("💡")
        self.bridge = Bridge('192.168.178.42')
        self.bridge.connect()
        self.menu = ["Toggle Lights"]
        self.add_scenes_to_menu()
        self.add_brightness_controls()
        self.menu.add(rumps.MenuItem("About", callback=self.open_about))

    def add_scenes_to_menu(self):
        scenes = self.bridge.get_scene()
        scenes_menu = rumps.MenuItem("Scenes")
        for scene_id, scene_data in scenes.items():
            scene_name = scene_data['name']
            scenes_menu.add(rumps.MenuItem(scene_name, callback=self.activate_scene))
        self.menu.add(scenes_menu)

    def add_brightness_controls(self):
        brightness_menu = rumps.MenuItem("Brightness")
        brightness_menu.add(rumps.MenuItem("Increase", callback=self.increase_brightness))
        brightness_menu.add(rumps.MenuItem("Decrease", callback=self.decrease_brightness))
        brightness_menu.add(rumps.MenuItem("Set to 100%", callback=self.set_full_brightness))
        brightness_menu.add(rumps.MenuItem("Set to 50%", callback=self.set_half_brightness))
        self.menu.add(brightness_menu)

    @rumps.clicked("Toggle Lights")
    def toggle_lights(self, _):
        lights = self.bridge.lights
        if any(light.on for light in lights):
            # If any light is on, turn all off
            for light in lights:
                light.on = False
            rumps.notification("Hue Lights", "All lights turned off", "")
        else:
            # If all lights are off, turn all on
            for light in lights:
                light.on = True
            rumps.notification("Hue Lights", "All lights turned on", "")

    def activate_scene(self, sender):
        scene_name = sender.title
        scenes = self.bridge.get_scene()
        scene_id = next(id for id, data in scenes.items() if data['name'] == scene_name)
        
        # Get all groups
        groups = self.bridge.get_group()
        
        # Activate the scene for each group
        for group_id in groups:
            self.bridge.activate_scene(group_id, scene_id)
        
        rumps.notification("Hue Lights", f"Activated scene: {scene_name}", "")

    def increase_brightness(self, _):
        self.adjust_brightness(25)

    def decrease_brightness(self, _):
        self.adjust_brightness(-25)

    def set_full_brightness(self, _):
        self.set_brightness(254)

    def set_half_brightness(self, _):
        self.set_brightness(127)

    def adjust_brightness(self, amount):
        for light in self.bridge.lights:
            if light.on:
                new_brightness = max(1, min(254, light.brightness + amount))
                light.brightness = new_brightness
        rumps.notification("Hue Lights", f"Brightness adjusted", "")

    def set_brightness(self, value):
        for light in self.bridge.lights:
            if light.on:
                light.brightness = value
        rumps.notification("Hue Lights", f"Brightness set to {value}", "")

    def open_about(self, _):
        webbrowser.open('https://mikka.is/hue/')

if __name__ == "__main__":
    HueLightsApp().run()
